# Requirements

All test images in this folder must be generated or freely licensed.

They should ideally all be regenerated (or, should they not be possible to create from scratch, re-downloaded from a reliable source) via "make sample_images".

# Licensed images

[source.jpg and many variants](https://commons.wikimedia.org/wiki/File:Katherine_Maher.jpg) - Victor Grigas - [CC BY-SA 3.0](https://creativecommons.org/licenses/by-sa/3.0/deed.en)

[watermark.svg watermark.png](https://commons.wikimedia.org/wiki/File:Wikimedia-logo.svg) - Public domain

[redeye.png](https://commons.wikimedia.org/wiki/File:BoldRedEye.JPG) - Public domain

[Guido-portrait-2014.jpg](https://commons.wikimedia.org/wiki/File:Guido-portrait-2014.jpg) - Daniel Stroud - [CC BY-SA 4.0](https://creativecommons.org/licenses/by-sa/4.0/deed.en)

[Coffee_berries_1.jpg](https://commons.wikimedia.org/wiki/File:Coffee_berries_1.jpg) - Stanislaw Szydlo - [CC BY-SA 3.0](https://creativecommons.org/licenses/by-sa/3.0/deed.en)

[A_small_cup_of_coffee.JPG](https://commons.wikimedia.org/wiki/File:A_small_cup_of_coffee.JPG) - Julius Schorzman - [CC BY-SA 2.0](https://creativecommons.org/licenses/by-sa/2.0/deed.en)

[Coffee_beans_-_ziarna_kawy.jpg](https://commons.wikimedia.org/wiki/File:Coffee_beans_-_ziarna_kawy.jpg) - Alina Zienowicz (Ala z) - [CC BY-SA 3.0](https://creativecommons.org/licenses/by-sa/3.0/deed.en)

[PNG_transparency_demonstration_1.png](https://commons.wikimedia.org/wiki/File:PNG_transparency_demonstration_1.png) - Ed g2s - [CC BY-SA 3.0](https://creativecommons.org/licenses/by-sa/3.0/deed.en)